@@ -3,7 +3,7 @@
 package KiokuDB;
 use Moose;
 
-our $VERSION = "0.29";
+our $VERSION = "0.30";
 
 use constant SERIAL_IDS => not not our $SERIAL_IDS;
 
@@ -23,6 +23,13 @@ use namespace::clean -except => [qw(meta SERIAL_IDS)];
 
 # with qw(KiokuDB::Role::API); # moved lower
 
+our $REQUIRED_CMD_VERSION = "0.01";
+sub cmd_is_up_to_date {
+    require KiokuDB::Cmd;
+    eval { KiokuDB::Cmd->VERSION($REQUIRED_CMD_VERSION); 1 };
+}
+
+
 sub connect {
     my ( $class, $dsn, @args ) = @_;
 
